# mkeima: Analyze flow cytometry-based mKeima assays in Python

[![Project Status: WIP – Initial development is in progress, but there has not yet been a stable, usable release suitable for the public.](https://www.repostatus.org/badges/latest/wip.svg)](https://www.repostatus.org/#wip)

mkeima is a Python library for the analysis and visualization of flow cytometry-based
mKeima assays.


## Installing mkeima

If you do not already have a Python installation, we recommend installing the
[Anaconda distribution](https://www.continuum.io/downloads) of Continuum Analytics,
which already contains a large number of popular Python packages for Data Science.
Alternatively, you can also get Python from the
[Python homepage](https://www.python.org/downloads/windows).

*Note* that the mkeima package requires Python version 3.9 or higher.

You can use pip to install mkeima from the [Python Package Index](https://pypi.org/)

```
pip install mkeima
```

To uninstall the mkeima package run the following command:

```
pip uninstall mkeima
```

### Installation when using Anaconda
If you are using Anaconda, you will need to install the mkeima package into a conda
environment. Open the Anaconda navigator, activate the conda environment you want to
use, run the "CMD.exe" application to open a terminal, and then use the pip install
command as described above.


## License
mkeima is licensed under the
[Apache License 2.0](http://www.apache.org/licenses/LICENSE-2.0.txt).


## Contributors
David M. Hollenstein https://github.com/hollenstein
